#!/usr/bin/env python
# -*- coding: utf-8 -*-

from datacollectorapi import client
from datacollectorapi import helper

def main():
    # Put your customer id and shared key below. For these info, see also
    # https://docs.microsoft.com/en-us/azure/log-analytics/log-analytics-data-collector-api#sample-requests
    customer_id = '<Customer ID aka WorkspaceID String>'
    shared_key =  '<Primary Key String>'
    log_type = 'ApacheAccessLog'

    json_records = []
    json_records.append(
        {
            "Log_ID": "5cdad72f-c848-4df0-8aaa-ffe033e75d57",
            "date":"2016-12-03 09:44:32 JST",
            "processing_time":"372",
            "remote":"101.202.74.59",
            "user":"-",
            "method":"GET / HTTP/1.1",
            "status":"304",
            "size":"-",
            "referer":"-",
            "agent":"Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:27.0) Gecko/20100101 Firefox/27.0"
        })

    json_records.append(
        {
            "Log_ID": "7260iswx-8034-4cc3-uirtx-f068dd4cd659",
            "date":"2016-12-03 09:45:14 JST",
            "processing_time":"105",
            "remote":"201.78.74.59",
            "user":"-",
            "method":"GET /manager/html HTTP/1.1",
            "status":"200",
            "size":"-",
            "referer":"-",
            "agent":"Mozilla/5.0 (Windows NT 5.1; rv:5.0) Gecko/20100101 Firefox/5.0"
        })

    endpoint = 'ods.opinsights.azure.com'
    api = client.DataCollectorAPIClient(customer_id, shared_key)   
    api = client.DataCollectorAPIClient(customer_id, shared_key, endpoint)   
    response = api.post_data(log_type, json_records)

    if (helper.is_success(response.status_code)):
        print( 'Succeeded in posting data to Data Collector API!!')
    else:
        print( "Failure: Error code:{}".format(response.status_code))

if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
import requests
import datetime
import hashlib
import hmac
import base64
import re
import simplejson as json

"""
This is Azure Log Analytics Data Collector API Client libraries

Data Collector API can be refered in the following document:
https://docs.microsoft.com/en-us/azure/log-analytics/log-analytics-data-collector-api
"""

__author__ = 'Yoichi Kawasaki'

### Global Defines
_LOG_ANALYTICS_DATA_COLLECTOR_API_VERSION = '2016-04-01'


class DataCollectorAPIClient:

    """
    Azure Log Analytics Data Collector API Client Class
    """

    def __init__(self, customer_id, shared_key, endpoint='ods.opinsights.azure.com'):
        self.customer_id = customer_id
        self.shared_key = shared_key
        self.endpoint = endpoint

    # Build the API signature
    def __signature(self, date, content_length):
        sigs= "POST\n{}\napplication/json\nx-ms-date:{}\n/api/logs".format(
                            str(content_length),date)
        utf8_sigs = sigs.encode('utf-8')
        decoded_shared_key = base64.b64decode(self.shared_key)
        hmac_sha256_sigs = hmac.new(
                decoded_shared_key, utf8_sigs,digestmod=hashlib.sha256).digest()
        encoded_hash = base64.b64encode(hmac_sha256_sigs).decode('utf-8')
        authorization = "SharedKey {}:{}".format(self.customer_id,encoded_hash)
        return authorization

    def __rfc1123date(self):
        return datetime.datetime.utcnow().strftime('%a, %d %b %Y %H:%M:%S GMT')

    def __is_valid_log_type(self, s):
        return True if ( re.match(r'^[a-zA-Z0-9_]+$', s) and len(s) <=100 ) else False

    # Build and send a request to the POST API
    def post_data(self, log_type, json_records, record_timestamp=''):
        # Check if string only contains alpha numeric and _, and not exceed 100 chars
        if not self.__is_valid_log_type(log_type):
            raise Exception(
                "ERROR: log_type must only contain alpha numeric and _, and not exceed 100 chars: {}".format(log_type))

        body = json.dumps(json_records)
        rfc1123date = self.__rfc1123date()
        content_length = len(body)
        signature = self.__signature(rfc1123date, content_length)
        uri = "https://{}.{}/api/logs?api-version={}".format(
                    self.customer_id,
                    self.endpoint,
                    _LOG_ANALYTICS_DATA_COLLECTOR_API_VERSION)

        """
        time-generated-field
        The name of a field in the data that contains the timestamp of the data item.
        If this isn’t specified, the default is the time that the message is ingested.
        The field format is ISO 8601 format YYYY-MM-DDThh:mm:ssZ
        """
        headers = {
            'content-type': 'application/json',
            'Authorization': signature,
            'Log-Type': log_type,
            'x-ms-date': rfc1123date,
            'time-generated-field': record_timestamp
        }
        return requests.post(uri,data=body, headers=headers)



import re
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('datacollectorapi/version.py', 'r') as fd:
    version = re.search(
        r'^VERSION\s*=\s*[\'"]([^\'"]*)[\'"]',
        fd.read(), re.MULTILINE).group(1)

setup(name='azure-log-analytics-data-collector-api',
    version=version,
    description='Azure Log Analytics Data Collector API Client',
    author='Yoichi Kawasaki',
    author_email='yokawasa@gmail.com',
    url='https://github.com/yokawasa/azure-log-analytics-data-collector-python',
    platforms='any',
    license='MIT',
    packages = ["datacollectorapi"],
    py_modules=['azure-log-analytics-data-collector-api'],
    install_requires=[
        'simplejson'
    ],
    classifiers=[
        'Intended Audience :: Developers',
        "License :: OSI Approved :: MIT License",
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Utilities',
    ],
    keywords='azure loganalysis datacollctorapi logs',
)
